screp-0.1.0.0: grep-like CLI using Parsec parsers instead of regex
Safe HaskellNone
LanguageHaskell2010

Scrappy.Files

Synopsis

Documentation

listFilesRecursive :: FilePath -> IO [FilePath] Source #

Recursively lists all files in a directory, returning absolute file paths.

countOccurrences :: [String] -> Map String Int Source #

Function to count occurrences of each unique string in a list