screp-0.1.0.0: grep-like CLI using Parsec parsers instead of regex
Safe HaskellNone
LanguageHaskell2010

Scrappy.Grep.Config

Synopsis

Documentation

runParserViaGhc Source #

Arguments

:: FilePath

Import file path (Parsers.hs)

-> String

Parser name (e.g., "email")

-> String

Content to search

-> IO (Either ConfigError [(Int, Int, String)]) 

Run a named parser from the import file via runghc Returns the matches as a list of (line, col, matchText)