| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Scrappy.Grep.Config
Synopsis
- runParserViaGhc :: FilePath -> String -> String -> IO (Either ConfigError [(Int, Int, String)])
- data ConfigError
Documentation
Arguments
| :: FilePath | Import file path (Parsers.hs) |
| -> String | Parser name (e.g., "email") |
| -> String | Content to search |
| -> IO (Either ConfigError [(Int, Int, String)]) |
Run a named parser from the import file via runghc Returns the matches as a list of (line, col, matchText)
data ConfigError Source #
Constructors
| ConfigFileNotFound FilePath | |
| GhcRunFailed String | |
| ParseResultFailed String |
Instances
| Show ConfigError Source # | |
Defined in Scrappy.Grep.Config Methods showsPrec :: Int -> ConfigError -> ShowS # show :: ConfigError -> String # showList :: [ConfigError] -> ShowS # | |
| Eq ConfigError Source # | |
Defined in Scrappy.Grep.Config | |